Skip to contents

A wrapper around ggplot2::guide_axis() that defaults to making transparent ticks and lines while preserving text, making it ideal for annotation labels.

Usage

guide_sec_axis_text(..., theme = NULL)

Arguments

...

Additional arguments passed to ggplot2::guide_axis(), such as title, check.overlap, or angle.

theme

A theme object to style the secondary axis.

Value

A guide object to be used in a scale's guide argument or within sec_axis_text().