Draws a line along an axis edge, with style defaults taken from the
axis.line element of the set theme. Requires coord_cartesian(clip = "off").
Usage
axis_line(
...,
position = NULL,
xintercept = NULL,
yintercept = NULL,
colour = NULL,
linewidth = NULL,
linetype = NULL
)Arguments
- ...
Not used. Forces named arguments.
- position
One of
"top","bottom","left", or"right". Inferred fromxinterceptoryinterceptif not provided.- xintercept
For
"left"/"right"axes: float the axis to this x position in data coordinates instead of the panel edge.- yintercept
For
"top"/"bottom"axes: float the axis to this y position in data coordinates instead of the panel edge.- colour
Inherits from
axis.linein the set theme.- linewidth
Inherits from
axis.linein the set theme. Supportsrel().- linetype
Inherits from
axis.linein the set theme.