Guide optimised for secondary axis text annotations
Source:R/sec-axis-text.R
guide_sec_axis_text.RdA wrapper around ggplot2::guide_axis() that defaults to making transparent
ticks and lines while preserving text, making it ideal for annotation labels.
Arguments
- ...
Additional arguments passed to
ggplot2::guide_axis(), such astitle,check.overlap, orangle.- theme
A theme object to style the secondary axis.
Value
A guide object to be used in a scale's guide argument or within
sec_axis_text().