Secondary axis for text annotations
Usage
sec_axis_text(
breaks = function(x) mean(x),
labels = ggplot2::waiver(),
name = NULL,
guide = guide_sec_axis_text(),
...
)Arguments
- breaks
A function or numeric vector giving the break position(s) used to anchor the text. Defaults to
NULL, which places a single label at the midpoint of the scale — the mean of the limits for continuous scales.- labels
One of:
A character vector of labels, the same length as
breaksA function that takes break positions as input and returns labels
- name
The name of the secondary axis. Use
ggplot2::waiver()to derive the name from the primary axis, orNULL(default) for no name.- guide
A guide object used to render the axis. Defaults to
guide_sec_axis_text(), which makes transparent ticks and lines.- ...
Additional arguments passed to
ggplot2::dup_axis().
Value
A AxisSecondary object for use in the sec.axis argument of
scale_x_continuous() or scale_y_continuous().
Examples
library(ggplot2)
library(dplyr)
set_theme(
ggrefine::theme_grey(
panel_heights = rep(unit(50, "mm"), 100),
panel_widths = rep(unit(75, "mm"), 100),
)
)
mtcars |>
ggplot(aes(x = wt, y = mpg, colour = as.factor(gear), fill = as.factor(gear))) +
scale_colour_discrete(palette = blends::multiply(get_theme()$palette.colour.discrete)) +
#clip = "off" is required for axis_text, axis_ticks and axis_bracket
coord_cartesian(clip = "off") +
#reference lines and shade
ggscribe::reference_line(xintercept = 2.4) +
ggscribe::reference_line(yintercept = 12) +
ggscribe::panel_shade(
xmin = 4,
xmax = 5,
) +
#top axis
scale_x_continuous(
sec.axis = ggscribe::sec_axis_text(
breaks = c(mean(c(4, 5))),
labels = c("Range"),
guide = ggscribe::guide_sec_axis_text(
angle = 90,
)
)
) +
ggscribe::axis_bracket(
position = "top",
breaks = c(4, 5),
) +
ggscribe::axis_text(
position = "top",
breaks = c(2.4),
labels = c("Threshold"),
) +
#right axis
ggscribe::axis_text(
position = "right",
breaks = 12,
labels = "Threshold",
) +
#geom
geom_point() +
#annotations fit plot
theme(plot.background = element_rect(colour = "grey92"))
#> Error in ggscribe::axis_bracket(position = "top", breaks = c(4, 5), ): unused argument (position = "top")